@@ -42,7 +42,7 @@ def register() -> Plugin:
             className='DetectAction',
             inputs=["payload"],
             outputs=['payload'],
-            version='0.1.1',
+            version='0.1.2',
             license="MIT",
             author="Patryk Migaj",
             init={
@@ -76,7 +76,7 @@ def register() -> Plugin:
             )
         ),
         metadata=MetaData(
-            name='tracardi-language-detection',
+            name='Language detection',
             desc='This plugin detect language from given string with meaningcloud API',
             type='flowNode',
             width=200,
